Allgemeine Schaltflächen

Allgemeine Schaltflächen | Tartalom

Untenstehend eine kurze Beschreibung jeder Schaltfläche.

| Félkövér szöveg.
| Dőlt szöveg .
| Aláhúzott szöveg .
| Áthúzott szöveg .
| Balra igazítás .
| Középre igazítás .
| Jobbra igazíás .
| Sorkizárt.
| Felsorolás / pontozott lista.
| Felsorolás / számozott lista.
| Behúzás balra .
| behúzás jobbra .
| Utolsó parancs visszavonása .
| Utolsó parancs ismétlése .
| Új link beillesztése, bővebb információért olvassa el a Link beillesztését.
| A kijelölt link eltávolítása / Az összes kijelölt link eltávolítása.
| Egy új kép beillesztése, bővebb információért olvassa el a Kép beillesztését .
| Kód tisztítása / Eltávolítja a nemkívánt formázásokat. Ez a funkció akkor hasznos, ha például Office dokumentumból másol tartalmat.
| Ennek a segítségnek az elérése.

Ugrás a Tartalomjegyzékre | ugrás a lap tetejére